######################################################################################################################
# Creating the file replicData.csv containing the attitudinal and behavioural indices at country-wave-year level: #
# Replicating the normalisation of indicators and the computaion of SDT indices                                      #
######################################################################################################################
# loading necessary package
library(tidyverse)

# loading data
yourPath = "" # give the path where you have stored the replicData.csv file
mydata = read_csv(paste0(yourPath, 'replicData.csv'))

# Variable names: Legend
# a003 = LEISURE, a173 = LIFECONTROL, d022 = MARR OUTDATED, d062 = HOME&KIDS, f028 = CHURCH, d019 = NEED KIDS, a025 = RESPECT, a049 = ABORTION
# agemoth1 = AGE1BIRTH, divmarpct = DIVRATE, fagemar1 = AGE1MARR, fmar1cum = MARRRATE, nmarpct = NONMARBIRTHS, teen = TEENFERT

##### Computing the normalised indicators #####
# attitudinal
att = mydata %>%
  select(country, year, wave, evsVar, evsValue) %>%
  distinct() %>%
  group_by(evsVar) %>%
  mutate(evsValueNorm = (evsValue - min(evsValue, na.rm = TRUE)) / (max(evsValue, na.rm = TRUE) - min(evsValue, na.rm = TRUE)) ) %>% # normalising the indicators
  mutate(evsValueNorm = ifelse(evsVar %in% c('f028', 'd062'), 1 - evsValueNorm, evsValueNorm) ) %>% # reversing the CHURCH and HOME&KIDS so that their high values appear as low in the index and they correspond to NO CHURCH and NO HOME&KIDS
  ungroup()

# behavioural
beh = mydata %>%
  select(country, year, demogIndic, demogValue) %>%
  distinct() %>%
  group_by(demogIndic) %>%
  mutate(demogValueNorm = (demogValue - min(demogValue, na.rm = TRUE)) / (max(demogValue, na.rm = TRUE) - min(demogValue, na.rm = TRUE)) ) %>% # normalising the indicators
  mutate(demogValueNorm = ifelse(demogIndic %in% c('teen', 'fmar1cum'), 1 - demogValueNorm, demogValueNorm) ) %>% # reversing the TEENFERT and MARRRATE so that their high values appear as low in the index
  ungroup()

##### Computing the SDT indices #####
# attitudinal (attIndex8: the 8-variable index, attIndex5: the 5-variable ones)
attIndex8 = att %>%
  group_by(country, year, wave) %>%
  summarise(attIndex8 = mean(evsValueNorm, na.rm = T) * 10) %>%
  ungroup()

attIndex5 = att %>%
  filter(!evsVar %in% c('a025', 'a049', 'd019')) %>%
  group_by(country, year, wave) %>%
  summarise(attIndex5 = mean(evsValueNorm, na.rm = T) * 10) %>%
  ungroup()

# behavioural
behIndex = beh %>%
  group_by(country, year) %>%
  summarise(behIndex = mean(demogValueNorm, na.rm = T) * 10) %>%
  ungroup()

##### Creating the final dataset #####
datafinal = full_join(att, beh) %>%
  left_join(attIndex8) %>%
  left_join(attIndex5) %>%
  left_join(behIndex)


